/// <reference types="node" />
/// <reference types="node" />
import type { ParsedUrlQueryInput } from 'node:querystring';
import type { UrlObject } from 'url';
import { AllLocales, Pathnames } from '../../shared/types';
import StrictParams from './StrictParams';
type SearchParamValue = ParsedUrlQueryInput[keyof ParsedUrlQueryInput];
type HrefOrHrefWithParamsImpl<Pathname, Other> = Pathname extends `${string}[[...${string}` ? // Optional catch-all
Pathname | ({
    pathname: Pathname;
    params?: StrictParams<Pathname>;
} & Other) : Pathname extends `${string}[${string}` ? // Required catch-all & regular params
{
    pathname: Pathname;
    params: StrictParams<Pathname>;
} & Other : // No params
Pathname | ({
    pathname: Pathname;
} & Other);
export type HrefOrUrlObjectWithParams<Pathname> = HrefOrHrefWithParamsImpl<Pathname, Omit<UrlObject, 'pathname'>>;
export type HrefOrHrefWithParams<Pathname> = HrefOrHrefWithParamsImpl<Pathname, {
    query?: Record<string, SearchParamValue>;
}>;
export declare function normalizeNameOrNameWithParams<Pathname>(href: HrefOrHrefWithParams<Pathname>): {
    pathname: Pathname;
    params?: StrictParams<Pathname>;
};
export declare function serializeSearchParams(searchParams: Record<string, SearchParamValue>): string;
type StrictUrlObject<Pathname> = Omit<UrlObject, 'pathname'> & {
    pathname: Pathname;
};
export declare function compileLocalizedPathname<Locales extends AllLocales, Pathname>(opts: {
    locale: Locales[number];
    pathname: Pathname;
    params?: StrictParams<Pathname>;
    pathnames: Pathnames<Locales>;
    query?: Record<string, SearchParamValue>;
}): string;
export declare function compileLocalizedPathname<Locales extends AllLocales, Pathname>(opts: {
    locale: Locales[number];
    pathname: StrictUrlObject<Pathname>;
    params?: StrictParams<Pathname>;
    pathnames: Pathnames<Locales>;
    query?: Record<string, SearchParamValue>;
}): UrlObject;
export declare function getRoute<Locales extends AllLocales>({ locale, pathname, pathnames }: {
    locale: Locales[number];
    pathname: string;
    pathnames: Pathnames<Locales>;
}): string;
export declare function getBasePath(pathname: string, windowPathname?: string): string;
export {};
